Save and load
-------------

.. currentmodule:: blosc2

.. autosummary::
   :toctree: autofiles/save_load/
   :nosignatures:

   save
   open
   save_array
   load_array
   save_tensor
   load_tensor
